@@ -10,7 +10,7 @@ CPAN
 =cut
 
 
-package Bio::Kmer 0.06;
+package Bio::Kmer 0.07;
 require 5.12.0;
 
 use strict;
@@ -49,7 +49,7 @@ local $SIG{'__DIE__'} = sub { my $e = $_[0]; $e =~ s/(at [^\s]+? line \d+\.$)/\n
 
 =head1 NAME
 
-Kmer
+Bio::Kmer
 
 =head1 SYNOPSIS
 
